'use client' // Error components must be Client Components

import { faHome, faRotate } from "@fortawesome/free-solid-svg-icons"
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome"
import Link from "next/link"
import { useEffect } from 'react'

export default function GlobalError({
	error,
	reset,
}: {
	error: Error
	reset: () => void
}) {
	useEffect(() => {
		// Log the error to an error reporting service
		console.error(error)
	}, [error])

	return (
		<div className=" overflow-x-hidden overflow-y-scroll bg-black ">
			<div className=" flex flex-col justify-center space-y-20 bg-white ">

				<div className="flex flex-col  items-center justify-center p-20">
					<h1 className="mt-4 text-3xl font-bold tracking-tight text-rfw-dark sm:text-5xl">
						Page not found
					</h1>

					<p className="mt-6 leading-7 text-gray-600">
						Sorry, we {"couldn't"} find the page {"you're"} looking for.
					</p>

					<div className="mt-10 flex gap-4 flex-col  md:flex-row items-center justify-center gap-x-6">
						<Link href={"/"} className="rfw-btn rfw-btn-primary flex items-center space-x-1">
							<span>	Go back home</span>
							<FontAwesomeIcon icon={faHome} className="h-4 w-4" />
						</Link>
						<button
							onClick={() => reset()}
							className="rfw-btn rfw-btn-primary-outline flex items-center space-x-1"
						>
							<span>Reload Page</span>
							<FontAwesomeIcon icon={faRotate} className="h-4 w-4" />
						</button>
					</div>



					<div className="mt-10 flex gap-4 flex-col  md:flex-row items-center justify-center gap-x-6">

						<a
							href="mailto:info@sfanonline.org"
							className="rfw-btn"
						>
							Contact Us <span aria-hidden="true">&rarr;</span>
						</a>
					</div>


				</div>
			</div>
		</div>
	)
}